@@ -82,8 +82,8 @@ class EWAHConstants:
         },
         DWH_ENGINE_SNOWFLAKE: {
             str: "VARCHAR",
-            int: "NUMBER",
-            float: "NUMBER",
+            int: "INTEGER",
+            float: "FLOAT",
             dict: "OBJECT",
             list: "ARRAY",
             tuple: "ARRAY",
@@ -96,14 +96,14 @@ class EWAHConstants:
         DWH_ENGINE_BIGQUERY: {
             str: "STRING",
             int: "INT64",
-            float: "NUMERIC",
+            float: "STRING",  # Numeric data types can break loading due to precision
             # Cannot use struct as data type because if there is any difference
             # in the structure of the mapping types, BigQuery loading will fail
-            dict: "STRING", # "STRUCT",
-            list: "STRING", # "STRUCT",
-            tuple: "STRING", # "STRUCT",
-            set: "STRING", # "STRUCT",
-            frozenset: "STRING", # "STRUCT",
+            dict: "STRING",  # "STRUCT",
+            list: "STRING",  # "STRUCT",
+            tuple: "STRING",  # "STRUCT",
+            set: "STRING",  # "STRUCT",
+            frozenset: "STRING",  # "STRUCT",
             bool: "BOOL",
             datetime: "TIMESTAMP",
             date: "DATE",
